@@ -1,8 +1,9 @@
+#-*- coding: utf-8 -*-
 from django.template import Library
-import math
 
 register = Library()
 
+
 def filer_staticmedia_prefix():
     """
     Returns the string contained in the setting FILER_STATICMEDIA_PREFIX.
